[evolution/webkit-composer: 146/150] Rename e_spell_dictionary_check() to check_word().



commit ef1bcfe3fc686ab3a0e08ae8a82f041df56e8f19
Author: Matthew Barnes <mbarnes redhat com>
Date:   Sun Jan 20 17:01:38 2013 -0500

    Rename e_spell_dictionary_check() to check_word().

 doc/reference/libeutil/libeutil-sections.txt |    2 +-
 e-util/e-spell-checker.c                     |    6 +++---
 e-util/e-spell-dictionary.c                  |   16 ++++++++--------
 e-util/e-spell-dictionary.h                  |    2 +-
 4 files changed, 13 insertions(+), 13 deletions(-)
---
diff --git a/doc/reference/libeutil/libeutil-sections.txt b/doc/reference/libeutil/libeutil-sections.txt
index 4bbe3a8..2c4138c 100644
--- a/doc/reference/libeutil/libeutil-sections.txt
+++ b/doc/reference/libeutil/libeutil-sections.txt
@@ -3679,7 +3679,7 @@ e_spell_dictionary_compare
 e_spell_dictionary_get_name
 e_spell_dictionary_get_code
 e_spell_dictionary_ref_spell_checker
-e_spell_dictionary_check
+e_spell_dictionary_check_word
 e_spell_dictionary_learn_word
 e_spell_dictionary_ignore_word
 e_spell_dictionary_get_suggestions
diff --git a/e-util/e-spell-dictionary.h b/e-util/e-spell-dictionary.h
index 77956fa..f36bfb4 100644
--- a/e-util/e-spell-dictionary.h
+++ b/e-util/e-spell-dictionary.h
@@ -74,7 +74,7 @@ const gchar *	e_spell_dictionary_get_name	(ESpellDictionary *dictionary);
 const gchar *	e_spell_dictionary_get_code	(ESpellDictionary *dictionary);
 ESpellChecker *	e_spell_dictionary_ref_spell_checker
 						(ESpellDictionary *dictionary);
-gboolean	e_spell_dictionary_check	(ESpellDictionary *dictionary,
+gboolean	e_spell_dictionary_check_word	(ESpellDictionary *dictionary,
 						 const gchar *word,
 						 gsize length);
 void		e_spell_dictionary_learn_word	(ESpellDictionary *dictionary,



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/e-util/e-spell-checker.c b/e-util/e-spell-checker.c
index 19ccfd2..997f1b3 100644
--- a/e-util/e-spell-checker.c
+++ b/e-util/e-spell-checker.c
@@ -708,8 +708,8 @@ e_spell_checker_count_active_languages (ESpellChecker *checker)
  * @word: a word to spell-check
  * @length: length of @word in bytes or -1 when %NULL-terminated
  *
  * Calls e_spell_dictionary_check() on all active dictionaries in @checker,
  * and returns %TRUE if @word is recognized by any of them.
  *
  * Returns: %TRUE if @word is recognized, %FALSE otherwise
  **/
@@ -730,7 +730,7 @@ e_spell_checker_check_word (ESpellChecker *checker,
 		ESpellDictionary *dictionary;
 
 		dictionary = E_SPELL_DICTIONARY (link->data);
-		if (e_spell_dictionary_check (dictionary, word, length)) {
+		if (e_spell_dictionary_check_word (dictionary, word, length)) {
 			recognized = TRUE;
 			break;
 		}
@@ -708,8 +708,8 @@ e_spell_checker_count_active_languages (ESpellChecker *checker)
  * @length: length of @word in bytes or -1 when %NULL-terminated
  *
- * Calls e_spell_dictionary_check() on all active dictionaries in @checker,
- * and returns %TRUE if @word is recognized by any of them.
+ * Calls e_spell_dictionary_check_word() on all active dictionaries in
+ * @checker, and returns %TRUE if @word is recognized by any of them.
  *
  * Returns: %TRUE if @word is recognized, %FALSE otherwise
diff --git a/e-util/e-spell-dictionary.c b/e-util/e-spell-dictionary.c
index a3f3be7..ce29477 100644
--- a/e-util/e-spell-dictionary.c
+++ b/e-util/e-spell-dictionary.c
@@ -604,7 +604,7 @@ e_spell_dictionary_ref_spell_checker (ESpellDictionary *dictionary)
 }
 
 /**
- * e_spell_dictionary_check:
+ * e_spell_dictionary_check_word:
  * @dictionary: an #ESpellDictionary
  * @word: a word to spell-check
  * @length: length of @word in bytes or -1 when %NULL-terminated
@@ -612,16 +612,16 @@ e_spell_dictionary_ref_spell_checker (ESpellDictionary *dictionary)
  * Tries to lookup the @word in the @dictionary to check whether
  * it's spelled correctly or not.
  *
  * Returns: %TRUE when the word is spelled correctly, %FALSE otherwise
  */
 gboolean
-e_spell_dictionary_check (ESpellDictionary *dictionary,
-                          const gchar *word,
-                          gsize length)
+e_spell_dictionary_check_word (ESpellDictionary *dictionary,
+                               const gchar *word,
+                               gsize length)
 {
 	ESpellChecker *spell_checker;
 	EnchantDict *enchant_dict;
-	gboolean correctly_spelled;
+	gboolean recognized;
 
 	g_return_val_if_fail (E_IS_SPELL_DICTIONARY (dictionary), TRUE);
 	g_return_val_if_fail (word != NULL && *word != '\0', TRUE);
@@ -633,11 +633,11 @@ e_spell_dictionary_check (ESpellDictionary *dictionary,
 		spell_checker, e_spell_dictionary_get_code (dictionary));
 	g_return_val_if_fail (enchant_dict != NULL, TRUE);
 
-	correctly_spelled = enchant_dict_check (enchant_dict, word, length);
+	recognized = enchant_dict_check (enchant_dict, word, length);
 
 	g_object_unref (spell_checker);
 
-	return correctly_spelled;
+	return recognized;
 }
 
 /**
@@ -612,16 +612,16 @@ e_spell_dictionary_ref_spell_checker (ESpellDictionary *dictionary)
  * it's spelled correctly or not.
  *
- * Returns: %TRUE when the word is spelled correctly, %FALSE otherwise
+ * Returns: %TRUE if @word is recognized, %FALSE otherwise
  */
 gboolean